.. _Configuration:

Configuration
=============

The following sections describe the configuration of the various Buildbot
components.  The information available here is sufficient to create basic
build and test configurations, and does not assume great familiarity with
Python.

More advanced Buildbot configurations, Buildbot acts as a framework for a
continuous-integration application.  The next section, :doc:`customization`,
describes this approach, with frequent references into Buildbot's
:ref:`Buildbot Development`.

.. toctree::
    :maxdepth: 2

    cfg-intro
    cfg-global
    cfg-changesources
    cfg-schedulers
    cfg-buildslaves
    cfg-builders
    cfg-buildfactories
    cfg-properties
    cfg-buildsteps
    cfg-interlocks
    cfg-statustargets
